decode_auth_payload_text

Function decode_auth_payload_text 

pub fn decode_auth_payload_text(
    payload: &str,
) -> Result<AuthPayload, WebSocketCloseCode>
Decodes the single auth envelope required as the first WebSocket frame.

Errors

Returns the close code for an invalid authentication batch.