pub fn decode_auth_payload_text(
payload: &str,
) -> Result<AuthPayload, WebSocketCloseCode>Expand description
Decodes the single auth envelope required as the first WebSocket frame.
Errors
Returns the close code for an invalid authentication batch.